@@ -3,8 +3,8 @@
 use strict;
 use warnings;
 
-use FindBin;
-use lib "$FindBin::Bin/../lib";
+use FindBin; # only for this example - load local Udev::FFI module
+use lib "$FindBin::Bin/../lib"; # only for this example - load local Udev::FFI module
 use Udev::FFI;
 
 
